Learn R Programming

boa (version 1.1.9)

boa.iter: Extract Iteration Numbers

Description

Extracts the iteration numbers from an MCMC sequence.

Usage

boa.iter(link)

Value

A numeric vector containing the iteration numbers in 'link'.

Arguments

link

Matrix whose columns and rows contain the monitored parameters and the MCMC iterations, respectively. The iteration numbers and parameter names must be assigned to dimnames(link).

Author

Brian J. Smith

See Also

boa.getiter, boa.pnames