Learn R Programming

boa (version 1.1.9)

boa.sortiter: Sort by Iteration Numbers

Description

Sorts an MCMC sequence by increasing iteration numbers.

Usage

boa.sortiter(link)

Value

A copy of 'link' with the rows sorted by increasing iteration numbers.

Arguments

link

Matrix whose columns and rows contain the monitored parameters and the MCMC iterations, respectively. The iteration numbers and parameter names must be assigned to dimnames(link).

Author

Brian J. Smith

See Also

boa.sortparms