Computes batch means for the parameters in an MCMC sequence.
boa.batchMeans(link, size)A matrix whose columns and rows contain the means within sequential batches and the monitored parameters, respectively.
Matrix whose columns and rows contain the monitored parameters
and the MCMC iterations, respectively. The iteration numbers and parameter
names must be assigned to dimnames(link).
Number of iterations to include in each batch.
Brian J. Smith