Learn R Programming

boa (version 1.1.7-2)

boa.chain: Session Lists of MCMC Sequences

Description

Extracts and sets the MCMC sequence(s) stored internally for use during a BOA session. Users can safely use this function to extract data. However, it should not be called directly to modify the stored MCMC sequence(s). Instead, data management should accomplished with the libboa.chain functions.

Usage

boa.chain(...)

Arguments

...
A list may be given as the only argument, or a character string given as the only argument, or any number of arguments may be in the = form, or no argument at all may be given. See the Value and Side Effects sections f

Value

  • If no arguments are supplied, a list of the current values is returned. If a character string is given, the current value of the named variable is returned. Otherwise, no values are returned.

Side Effects

When variables are set, boa.chain() modifies the internal list .boa.chain. If boa.chain() is called with either a list as the single argument, or with one or more arguments in the = form, the variables specified by the names in the arguments are modified.