boa.chain(...) = form, or no argument at all may be given. See the
Value and Side Effects sections f.boa.chain.
If boa.chain() is called with either a list as the single argument, or with one
or more arguments in the = form, the variables specified
by the names in the arguments are modified.