Returns summary information from a list of MCMC sequences.
boa.chain.info(chain, chain.support)
Character vector giving the names of the MCMC sequences in the session list of sequences.
List of character vectors giving the parameter names in each of the MCMC sequences.
List of numeric vectors giving the iterations from each MCMC sequence.
Matrix whose columns give the range of the iterations for the MCMC sequences named in the rows.
List of numeric vectors giving the support for the parameters in each of the MCMC sequences.
List of matrices whose columns and rows contain the monitored parameters and the MCMC iterations, respectively. The iteration numbers and parameter names must be assigned to the dimnames.
List of matrices whose columns and rows contain the monitored parameters and the support (lower and upper limits), respectively.
Brian J. Smith
boa.print.info