Learn R Programming

boa (version 1.1.9)

boa.getiter: Extract Iterations

Description

Extracts a subset of the iterations in an MCMC sequence.

Usage

boa.getiter(link, iter)

Value

A subset of 'link' containing all prior parameters and the iterations specified in 'iter'.

Arguments

link

Matrix whose columns and rows contain the monitored parameters and the MCMC iterations, respectively. The iteration numbers and parameter names must be assigned to dimnames(link).

iter

Numeric vector containing the iterations to extract from 'link'.

Author

Brian J. Smith

See Also

boa.iter, boa.getparms