Extracts a subset of the iterations in an MCMC sequence.
boa.getiter(link, iter)A subset of 'link' containing all prior parameters and the iterations specified in 'iter'.
Matrix whose columns and rows contain the monitored parameters
and the MCMC iterations, respectively. The iteration numbers and parameter
names must be assigned to dimnames(link).
Numeric vector containing the iterations to extract from 'link'.
Brian J. Smith
boa.iter, boa.getparms