Learn R Programming

boa (version 1.1.9)

boa.getparms: Extract Parameters

Description

Extracts a subset of the parameters in an MCMC sequence.

Usage

boa.getparms(link, pnames)

Value

A subset of 'link' containing the specified parameters in 'pnames' and all prior iterations.

Arguments

link

Matrix whose columns and rows contain the monitored parameters and the MCMC iterations, respectively. The iteration numbers and parameter names must be assigned to dimnames(link).

pnames

Character vector containing the names of the parameters to extract from 'link'.

Author

Brian J. Smith

See Also

boa.getiter, boa.pnames