Extracts a subset of the parameters in an MCMC sequence.
boa.getparms(link, pnames)A subset of 'link' containing the specified parameters in 'pnames' and all prior iterations.
Matrix whose columns and rows contain the monitored parameters
and the MCMC iterations, respectively. The iteration numbers and parameter
names must be assigned to dimnames(link).
Character vector containing the names of the parameters to extract from 'link'.
Brian J. Smith
boa.getiter, boa.pnames