Loads the data and global parameter settings from a previously saved BOA session.
boa.load(name, envir = globalenv())A logical value indicating that the object was successfully loaded.
Character string giving the name of the object containing the session to be loaded.
The 'environment' from which the object should come. For more
information, consult the help documentation in R on the get function.
Brian J. Smith