Learn R Programming

boa (version 1.1.7-2)

boa.par: Global Parameters

Description

Displays and sets the global parameters stored internally for use during a BOA session.

Usage

boa.par(...)

Arguments

...
A list may be given as the only argument, or a character string given as the only argument, or any number of arguments may be in the = form, or no argument at all may be given.

Value

  • If no arguments are supplied, a list of the current values is returned. If a character string is given, the current value of the named variable is returned. Otherwise, a list of the named variables and their old values is returned, but not printed.

Side Effects

When variables are set, boa.par() modifies the internal list .boa.par. If boa.par() is called with either a list as the single argument, or with one or more arguments in the = form, the variables specified by the names in the arguments are modified.