Creates a single plot of the lag autocorrelations for a specified parameter.
boa.plot.acf(lname, pname, annotate = boa.par("legend"))A logical value indicating that the plot was successfully created.
Character string giving the name of the desired MCMC sequence in the working session list of sequences.
Character string giving the name of the parameter to be plotted.
Logical value indicating that a legend be included in the plot.
Brian J. Smith
boa.acf, boa.print.acf