boa.plot.close: Close Graphics Windows
Description
Closes graphics windows opened with boa.plot.open().
Usage
boa.plot.close(which = dev.cur())
Value
If the specified graphics windows are successfully closed, the number of the
current graphics window is returned. Otherwise NULL is returned.
Arguments
- which
Integer vector specifying the graphics windows to be closed.