powered by
Adds a title to the graphics window. This function should be called after all plots have been added to the target graphics window.
boa.plot.title(text)
Character string giving the title to be centered and displayed across the top of the graphics window.
Brian J. Smith