Displays, in a single plot, the trace histories for the specified parameter(s).
boa.plot.trace(lnames, pname, annotate = boa.par("legend"))A logical value indicating that the plot was successfully created.
Character vector giving the name of the desired MCMC sequence in the working session list of sequences.
Character string giving the name of the parameters to be plotted.
Logical value indicating that a legend be included in the plot.
Brian J. Smith
boa.plot