Learn R Programming

boa (version 1.1.9)

boa.print.cor: Print Correlation Matrices

Description

Iteratively computes and displays the correlation matrices for the parameters in each of the MCMC sequences in the working session list of sequences.

Usage

boa.print.cor()

Arguments

Author

Brian J. Smith