Iteratively calls boa.handw() to display the Heidelberger and Welch convergence diagnostics for the parameters in each of the MCMC sequences in the working session list of sequences.
boa.print.handw(error = boa.par("handw.error"), alpha = boa.par("alpha"))
Accuracy of the posterior estimates for the monitored parameters.
Alpha level for the confidence in the sample mean of the retained iterations.
Brian J. Smith
boa.handw