Save the current state of the session lists of MCMC sequences and the global parameters to a database object.
boa.save(name, envir = globalenv())A logical value indicating that the session was successfully saved to the specified object.
Character string giving the name of the object to which the current session should be saved.
The 'environment' to which the object should be saved. For more information, consult the help documentation in R on the assign() function.
Brian J. Smith