Applies a log or logit transformation to map bounded variables to the entire real line.
boa.transform(x, support, inv = FALSE)Transformed or inverse-transformed analogue of 'x'.
Numeric object to be transformed.
Vector giving the lower and upper limits of the support for the untransformed data. Unbounded lower or upper limits should be specified as -Inf or Inf, respectively.
Logical value indicating that the inverse transformation should be applied.
Brian J. Smith